@@ -583,7 +583,8 @@ class FlickrUserPhotostreamMirroringAgent:
                     if index > 99:
                         index = 0
                         page += 1
-                        photos = self.__API.get_photos(self.user.id, page, 100)[0]
+                        photos = self.__API.get_photos(
+                            self.user.id, page, 100)[0]
 
                 self.__cache["number_of_new_photos"] += index + (page - 1)*100
 
@@ -598,7 +599,8 @@ class FlickrUserPhotostreamMirroringAgent:
 
                     self.__cache["new_photos"] = [index, page]
                     for i in range(page):
-                        self.__cache["new_photo_pages"].append(i + 1)
+                        if (i + 1) not in self.__cache["new_photo_pages"]:
+                            self.__cache["new_photo_pages"].append(i + 1)
         else:
             self.__cache = cache_data
 
